@@ -12,10 +12,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import configparser
 import os
 
-import six
-import six.moves.configparser as config_parser
 from tempest.lib.cli import base
 from tempest.lib.common.utils import data_utils
 from tempest.lib import exceptions
@@ -37,7 +36,8 @@ class FunctionalTestBase(base.ClientTestBase):
     def _get_clients(self):
         # NOTE(aarefiev): {toxinidir} is a current working directory, so
         # the tox env path is {toxinidir}/.tox
-        cli_dir = os.path.join(os.path.abspath('.'), '.tox/functional/bin')
+        venv_name = os.environ.get('OS_TESTENV_NAME', 'functional')
+        cli_dir = os.path.join(os.path.abspath('.'), '.tox/%s/bin' % venv_name)
 
         config = self._get_config()
         if config.get('os_auth_url'):
@@ -52,25 +52,19 @@ class FunctionalTestBase(base.ClientTestBase):
                     setattr(self, domain_attr, config[domain_attr])
         else:
             self.ironic_url = config['ironic_url']
-            self.os_auth_token = config['os_auth_token']
             client = base.CLIClient(cli_dir=cli_dir,
-                                    ironic_url=self.ironic_url,
-                                    os_auth_token=self.os_auth_token)
+                                    ironic_url=self.ironic_url)
         return client
 
     def _get_config(self):
         config_file = os.environ.get('IRONICCLIENT_TEST_CONFIG',
                                      DEFAULT_CONFIG_FILE)
-        # SafeConfigParser was deprecated in Python 3.2
-        if six.PY3:
-            config = config_parser.ConfigParser()
-        else:
-            config = config_parser.SafeConfigParser()
+        config = configparser.ConfigParser()
         if not config.read(config_file):
             self.skipTest('Skipping, no test config found @ %s' % config_file)
         try:
             auth_strategy = config.get('functional', 'auth_strategy')
-        except config_parser.NoOptionError:
+        except configparser.NoOptionError:
             auth_strategy = 'keystone'
         if auth_strategy not in ['keystone', 'noauth']:
             raise self.fail(
@@ -86,14 +80,14 @@ class FunctionalTestBase(base.ClientTestBase):
                                           'os_project_domain_id',
                                           'os_identity_api_version']
         else:
-            conf_settings += ['os_auth_token', 'ironic_url']
+            conf_settings += ['ironic_url']
 
         cli_flags = {}
         missing = []
         for c in conf_settings + keystone_v3_conf_settings:
             try:
                 cli_flags[c] = config.get('functional', c)
-            except config_parser.NoOptionError:
+            except configparser.NoOptionError:
                 # NOTE(vdrok): Here we ignore the absence of KS v3 options as
                 # v2 may be used. Keystone client will do the actual check of
                 # the parameters' correctness.
@@ -119,10 +113,9 @@ class FunctionalTestBase(base.ClientTestBase):
         :param params: optional positional args to use
         :type params: string
         """
-        flags = ('--os_auth_token %(token)s --ironic_url %(url)s %(flags)s'
+        flags = ('--os-endpoint %(url)s %(flags)s'
                  %
-                 {'token': self.os_auth_token,
-                  'url': self.ironic_url,
+                 {'url': self.ironic_url,
                   'flags': flags})
         return base.execute(cmd, action, flags, params,
                             cli_dir=self.client.cli_dir)
@@ -144,12 +137,15 @@ class FunctionalTestBase(base.ClientTestBase):
         """
         if cmd == 'openstack':
             config = self._get_config()
-            id_api_version = config['os_identity_api_version']
-            flags += ' --os-identity-api-version {0}'.format(id_api_version)
+            id_api_version = config.get('os_identity_api_version')
+            if id_api_version:
+                flags += ' --os-identity-api-version {}'.format(id_api_version)
         else:
             flags += ' --os-endpoint-type publicURL'
 
-        if hasattr(self, 'os_auth_token'):
+        if hasattr(self, 'ironic_url'):
+            if cmd == 'openstack':
+                flags += ' --os-auth-type none'
             return self._cmd_no_auth(cmd, action, flags, params)
         else:
             for keystone_object in 'user', 'project':
@@ -231,7 +227,7 @@ class FunctionalTestBase(base.ClientTestBase):
                 self.fail('Ironic node {0} has not been deleted!'
                           .format(node_id))
 
-    def create_node(self, driver='fake', params=''):
+    def create_node(self, driver='fake-hardware', params=''):
         node = self.ironic('node-create',
                            params='--driver {0} {1}'.format(driver, params))
 
