@@ -13,11 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
+import json
 import time
-
-import mock
-from oslo_serialization import jsonutils
-from six.moves import http_client
+from unittest import mock
 
 from keystoneauth1 import exceptions as kexc
 
@@ -41,9 +40,9 @@ def _get_error_body(faultstring=None, debuginfo=None, description=None):
             'faultstring': faultstring,
             'debuginfo': debuginfo
         }
-    raw_error_body = jsonutils.dump_as_bytes(error_body)
+    raw_error_body = json.dumps(error_body)
     body = {'error_message': raw_error_body}
-    return jsonutils.dumps(body)
+    return json.dumps(body)
 
 
 def _session_client(**kwargs):
@@ -403,6 +402,39 @@ class SessionClientTest(utils.BaseTestCase):
             user_agent=http.USER_AGENT)
         self.assertEqual(res, session.request.return_value)
 
+    @mock.patch.object(http.SessionClient, 'get_endpoint', autospec=True)
+    def test_endpoint_not_found(self, mock_get_endpoint):
+        mock_get_endpoint.return_value = None
+
+        self.assertRaises(exc.EndpointNotFound, _session_client,
+                          session=utils.mockSession({}))
+
+    def test_json_request(self):
+        session = utils.mockSession({}, status_code=200)
+        req_id = "req-7b081d28-8272-45f4-9cf6-89649c1c7a1a"
+        client = _session_client(
+            session=session, additional_headers={"foo": "bar"},
+            global_request_id=req_id)
+        client.json_request('GET', 'url')
+
+        session.request.assert_called_once_with(
+            'url', 'GET', raise_exc=False, auth=None,
+            headers={
+                "foo": "bar",
+                "X-OpenStack-Request-ID": req_id,
+                "Content-Type": "application/json",
+                "Accept": "application/json",
+                "X-OpenStack-Ironic-API-Version": "1.6"
+            },
+            endpoint_filter={
+                'interface': 'publicURL',
+                'service_type': 'baremetal',
+                'region_name': ''
+            },
+            endpoint_override='http://localhost:1234',
+            user_agent=http.USER_AGENT
+        )
+
 
 @mock.patch.object(time, 'sleep', lambda *_: None)
 class RetriesTestCase(utils.BaseTestCase):
