@@ -714,12 +714,16 @@ class NodeManager(base.CreateManager):
         path = "%s/states/provision" % node_uuid
         body = {'target': state}
         if configdrive:
-            if not isinstance(configdrive, dict):
+            if isinstance(configdrive, str):
                 if os.path.isfile(configdrive):
                     with open(configdrive, 'rb') as f:
                         configdrive = f.read()
-                if os.path.isdir(configdrive):
+                elif os.path.isdir(configdrive):
                     configdrive = utils.make_configdrive(configdrive)
+                else:
+                    raise ValueError('Config drive seems to refer to a file '
+                                     'or directory but this file/directory '
+                                     'does not exist: %s.' % configdrive)
 
             if isinstance(configdrive, bytes):
                 try:
@@ -1008,3 +1012,56 @@ class NodeManager(base.CreateManager):
                       '%(state)s, the current state is %(actual)s',
                       {'node': node_ident, 'state': expected_state,
                        'actual': node.provision_state})
+
+    def get_history_list(self,
+                         node_ident,
+                         detail=False,
+                         os_ironic_api_version=None,
+                         global_request_id=None):
+        """Get node history event list.
+
+        Provides the ability to query a node event history list from
+        the API and return the API response to the caller.
+
+        Requires API version 1.78.
+
+        :param node_ident: The name or UUID of the node.
+        :param detail: If detailed data should be returned in the
+                       event list entry. Default False.
+        :param os_ironic_api_version: String version (e.g. "1.35") to use for
+            the request.  If not specified, the client's default is used.
+        :param global_request_id: String containing global request ID header
+            value (in form "req-<UUID>") to use for the request.
+        """
+        path = "%s/history" % node_ident
+
+        if detail:
+            path = path + '/detail'
+
+        return self._list_primitives(
+            self._path(path), 'history',
+            os_ironic_api_version=os_ironic_api_version,
+            global_request_id=global_request_id)
+
+    def get_history_event(self,
+                          node_ident,
+                          event,
+                          os_ironic_api_version=None,
+                          global_request_id=None):
+        """Get a single event record for a node.
+
+        Provides the ability to request, and return
+        a node's single vent hisotyr entry.
+
+        :param node_ident: The name or UUID of the node.
+        :param event: The UUID of the event entry as listed
+                      in the node event history list.
+        :param os_ironic_api_version: String version (e.g. "1.35") to use for
+            the request.  If not specified, the client's default is used.
+        :param global_request_id: String containing global request ID header
+            value (in form "req-<UUID>") to use for the request.
+        """
+        path = "%s/history/%s" % (node_ident, event)
+        return self._get_as_dict(
+            path, os_ironic_api_version=os_ironic_api_version,
+            global_request_id=global_request_id)
